##  Filtering from SAP LeanIX to ServiceNow
When SAP LeanIX is the source system, you can apply inventory filters to fact sheet mappings to only send specific fact sheet fields to the corresponding ServiceNow table. Here are examples of frequently used filters for application fact sheets:
  * Approved quality seal: Only send applications that have an approved quality seal to ServiceNow.
  * Active lifecycle phase: Only send applications that are in the Active lifecycle phase to ServiceNow.


To add a filter, follow these steps:
  1. Hover over a fact sheet mapping where the synchronization direction is from LeanIX, then click Filters under Filter.
![Configuring Sync Filters when SAP LeanIX Is the Source System](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ae5e57a441014853aaee7214fec52_LowRes.png)
Configuring Sync Filters when SAP LeanIX Is the Source System
  2. In the filter overlay that appears, select fact sheet attributes to be synchronized, then click Use Fact Sheet Filter.
  3. Save your changes.
